@@ -14,7 +14,7 @@ automatically if you have that package installed.
 """
 
 import os
-from binascii import unhexlify
+from binascii import hexlify, unhexlify
 
 
 class Key(object):
@@ -45,8 +45,8 @@ class Key(object):
 #  These constants are needed for encoding the name of the hash
 #  algorithm into the RSA signature, per PKCS #1.
 RSA_DIGESTINFO_HEADER = {
-    "sha1": "3021300906052b0e03021a05000414",
-    "sha256": "3031300d060960864801650304020105000420",
+    "sha1": b"3021300906052b0e03021a05000414",
+    "sha256": b"3031300d060960864801650304020105000420",
 }
 
 
@@ -68,33 +68,34 @@ class RSKey(Key):
 
     def __init__(self, data):
         _check_keys(data, ("e", "n"))
-        self.e = long(data["e"])
-        self.n = long(data["n"])
+        self.e = int(data["e"])
+        self.n = int(data["n"])
         try:
-            self.d = long(data["d"])
+            self.d = int(data["d"])
         except KeyError:
             self.d = None
 
     def verify(self, signed_data, signature):
         n, e = self.n, self.e
-        m = long(signature.encode("hex"), 16)
+        m = int(hexlify(signature), 16)
         c = pow(m, e, n)
-        padded_digest = hex(c)[2:].rstrip("L").rjust(self.DIGESTSIZE, "0")
+        digest = hex(c)[2:].rstrip("L").encode("ascii")
+        padded_digest = digest.rjust(self.DIGESTSIZE, b"0")
         return padded_digest == self._get_digest(signed_data)
 
     def sign(self, data):
         n, e, d = self.n, self.e, self.d
         if not d:
             raise ValueError("private key not present")
-        c = long(self._get_digest(data), 16)
+        c = int(self._get_digest(data), 16)
         m = pow(c, d, n)
-        return unhexlify(hex(m)[2:].rstrip("L"))
+        return unhexlify(hex(m)[2:].rstrip("L").encode("ascii"))
 
     def _get_digest(self, data):
-        digest = self.HASHMOD(data).hexdigest()
-        padded_digest = "00" + RSA_DIGESTINFO_HEADER[self.HASHNAME] + digest
+        digest = self.HASHMOD(data).hexdigest().encode("ascii")
+        padded_digest = b"00" + RSA_DIGESTINFO_HEADER[self.HASHNAME] + digest
         padding_len = (self.DIGESTSIZE) - 4 - len(padded_digest)
-        padded_digest = "0001" + ("f" * padding_len) + padded_digest
+        padded_digest = b"0001" + (b"f" * padding_len) + padded_digest
         return padded_digest
 
 
@@ -111,30 +112,30 @@ class DSKey(Key):
 
     def __init__(self, data):
         _check_keys(data, ("p", "q", "g", "y"))
-        self.p = long(data["p"], 16)
-        self.q = long(data["q"], 16)
-        self.g = long(data["g"], 16)
-        self.y = long(data["y"], 16)
+        self.p = int(data["p"], 16)
+        self.q = int(data["q"], 16)
+        self.g = int(data["g"], 16)
+        self.y = int(data["y"], 16)
         if "x" in data:
-            self.x = long(data["x"], 16)
+            self.x = int(data["x"], 16)
         else:
             self.x = None
 
     def verify(self, signed_data, signature):
         p, q, g, y = self.p, self.q, self.g, self.y
-        signature = signature.encode("hex")
-        hexlength = self.BITLENGTH / 4
-        signature = signature.rjust(hexlength * 2, "0")
+        signature = hexlify(signature)
+        hexlength = self.BITLENGTH // 4
+        signature = signature.rjust(hexlength * 2, b"0")
         if len(signature) != hexlength * 2:
             return False
-        r = long(signature[:hexlength], 16)
-        s = long(signature[hexlength:], 16)
+        r = int(signature[:hexlength], 16)
+        s = int(signature[hexlength:], 16)
         if r <= 0 or r >= q:
             return False
         if s <= 0 or s >= q:
             return False
         w = modinv(s, q)
-        u1 = (long(self.HASHMOD(signed_data).hexdigest(), 16) * w) % q
+        u1 = (int(self.HASHMOD(signed_data).hexdigest(), 16) * w) % q
         u2 = (r * w) % q
         v = ((pow(g, u1, p) * pow(y, u2, p)) % p) % q
         return (v == r)
@@ -146,22 +147,22 @@ class DSKey(Key):
         # We need to do lots of if-not-this-then-start-over type tests.
         # A while loop with continue statements is the cleanest way to do so.
         while True:
-            k = long(os.urandom(self.BITLENGTH / 8).encode("hex"), 16) % q
+            k = int(hexlify(os.urandom(self.BITLENGTH // 8)), 16) % q
             if k == 0:
                 continue
             r = pow(g, k, p) % q
             if r == 0:
                 continue
-            h = (long(self.HASHMOD(data).hexdigest(), 16) + (x * r)) % q
+            h = (int(self.HASHMOD(data).hexdigest(), 16) + (x * r)) % q
             s = (modinv(k, q) * h) % q
             if s == 0:
                 continue
             break
         assert 0 < r < q
         assert 0 < s < q
-        bytelength = self.BITLENGTH / 8
-        r_bytes = int2bytes(r).rjust(bytelength, "\x00")
-        s_bytes = int2bytes(s).rjust(bytelength, "\x00")
+        bytelength = self.BITLENGTH // 8
+        r_bytes = int2bytes(r).rjust(bytelength, b"\x00")
+        s_bytes = int2bytes(s).rjust(bytelength, b"\x00")
         return r_bytes + s_bytes
 
 
@@ -182,13 +183,13 @@ def modinv(a, m):
 
 
 def int2bytes(x):
-    """Convert a Python long integer to bigendian bytestring."""
+    """Convert a Python integer to bigendian bytestring."""
     # It's faster to go via hex encoding in C code than it is to try
     # encoding directly into binary with a python-level loop.
     # (and hex-slice-strip seems consistently faster than using "%x" format)
-    hexbytes = hex(x)[2:].rstrip("L")
+    hexbytes = hex(x)[2:].rstrip("L").encode("ascii")
     if len(hexbytes) % 2:
-        hexbytes = "0" + hexbytes
+        hexbytes = b"0" + hexbytes
     return unhexlify(hexbytes)
 
 
